core

package module
v0.0.0-...-08d3913 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 12, 2023 License: MIT Imports: 3 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Error

type Error struct {
	ID    ulid.ULID // unique error ID
	Name  string    // human friendly name (naming convention is to prefix the name with "Err")
	Err   error     // underlying error
	Cause error     // error chain
}

func (Error) Error

func (e Error) Error() string

func (Error) Is

func (e Error) Is(err error) bool

Is reports true if the err type is Error and if the ID matches. Otherwise, check the error against its cause.

func (Error) Unwrap

func (e Error) Unwrap() error

Directories

Path Synopsis

Jump to